package com.changhong.ippmodel;

import java.util.List;

/**
 * @version 1.0 IppCore 协议接口
 * 
 *          {@link #onUpdateValuesList(List<IppEventMsg> events)} 协议Ipp事件更新接口
 * 
 * 
 *          {@link #onDeviceRemove(int id)} ipp设备离线通知事件
 * 
 * 
 * 
 * 
 *          {@link #onDeviceAdd(IppDevice newdevice)} ipp设备在线通知事件
 * 
 * */
public interface IIppEvent // extends UpnpControllerInterface
{

	/**
	 * IPP协议事件更新接口
	 * 
	 * @param events
	 *            {@link#List<IppEventMsg>}
	 * 
	 * @return void
	 */
	void onDeviceEventUpdate(int eventtype, int eventvalue);

	void onDeviceEventReport(IppDevice dev, int eventtype, int param1,
			String param2);

	void onUpdateValuesList(List<IppEventMsg> events);

	/**
	 * ipp设备离线通知事件
	 * 
	 * @param events
	 *            {@link#IppEventMsg}
	 * @return void
	 */
	void onDeviceRemove(int id);

	/**
	 * ipp设备在线通知事件
	 * 
	 * @param newdevice
	 *            {@link}#IppDevice} 上线的新设备
	 * @return void
	 */
	void onDeviceAdd(IppDevice newdevice);

	void onIPPDeviceSetAck(IppDevice dev, int funid, int isok);

	void onIPPNetworkDisconnect();

	void onRecvVoiceMsg(VoiceMsg msg);

	void onSendVoiceMsgResponse(int recvusr, boolean success);

	void onMsgReceived(IPPMsg msg);
	//void onMsgReceived(IPPMsg msg,byte [] raw);
	void onIPPDeviceChannelChange(String ownerID, String devsn, String channelid,
			String channelname);

	void onFriendOnline(String friendID, boolean online);

	void onDeviceOnline(String ownerID, String devsn, int devtype, boolean online);

	void onKickOff(String userid, int logintype, String msg);
	
	void onMinaReturn(String json);
	void onGetScreen(int devid,byte[]  bitmap);
//	void onTransportSta
//****************************************************************************//
	/**
	 * 状态通知接口
	 * @param id：所连接智能烟灶的ID
	 * @param status：烟灶所有状态
	 * @return
	 */
	void OnSendHocoStatus(int id, IppHocoStatus status);
	
	/**
	 * 报警事件接口
	 * @param id：所连接智能烟灶的ID
	* @param mError：故障码
	 * 0x0100： 烟机SOC故障
	 * 0x0200：烟机SOC
	 * 0x0300：智能灶故障
	 * @param mErrorValue：故障值
	 * 		故障类		故障码		故障值
	 *	|烟机SOC故障	0x0100: 1——串口通信故障;
	 *									2——wifi模块异常;
	 *									4——文件存储空间报警;
	 *	|烟机SOC故障	0x0200:	1——烟雾报警;
	 *									2——照明故障;
	 *									4——风机运行故障;
	 *									8——烟雾传感器故障;
	 *									16——RF通信故障;
	 *	|智能灶故障		0x0300:	1——燃气泄漏;
	 *									2——点火失败;
	 *									4——意外熄火;
	 *									8——燃气传感器故障;
	 * @return 
	 */
	void OnErrorSend(int id,int mError, int mErrorValue);

	void OnSendCookerTotalTime(int id, int cookernum, int totaltime);//灶口本次开火累计时间
	
	void OnSendCookerTimeLeft(int id, int timenum, int timeleft);//灶口本次开火累计时间
	/**
	 * 高成本状态通知接口
	 * @param id：所连接智能烟灶的ID
	 * @param status：烟灶所有状态
	 * @return
	 */
	void OnSendHighHocoStatus(int id, IppHocoStatus status);
	void OnStatusReport(String uuid, String heaterstatus);
	
	void onDeviceEvent(IppDevice dev, String data, int length);
	
	void onDeviceEvent(IppDevice dev, byte[] data);
	
}

