package com.changhong.ippservice;

import java.util.List;

import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.util.Log;

import com.changhong.ippjni.IppCoreJni;
import com.changhong.ippmodel.IIppEvent;
import com.changhong.ippmodel.IPPMsg;
import com.changhong.ippmodel.IppDevice;
import com.changhong.ippmodel.IppEventMsg;
import com.changhong.ippmodel.IppHocoStatus;
import com.changhong.ippmodel.VoiceMsg;

/**
 * Ipp服务的控制
 * 	  使用：开启ipp查询服务：startService()
 * 		    关闭ipp查询服务：stopServce()
 * 		    注销ipp查询服务：destoryService(), 在退出app或activity时使用此方法关闭执行ipp控制的线程
 * 
 * @author tanglong
 */
@SuppressWarnings("deprecation")
public class IppServiceManager implements IServiceManager {
	private static final String TAG = IppServiceManager.class.getSimpleName();
	
	private static IIppEvent mEvent;
	private EventHandler mHandler;
	private HandlerThread eventThread = new HandlerThread("IppEventThread");
	
	public IppServiceManager() {
		eventThread.start();
		mHandler = new EventHandler(eventThread.getLooper());
	}
	
	public void stopService() {
		Message msg = mHandler.obtainMessage(EventHandler.EVENT_IPP_STOP);
        msg.sendToTarget();
	}
	
	public void destoryService() {
		Message msg = mHandler.obtainMessage(EventHandler.EVENT_IPP_DESTORY);
        msg.sendToTarget();
	}
	
	public void startService() {
		try {
			startWithThrow();
		} catch (ServiceStartException e) {
			e.printStackTrace();
		}
		Message msg = mHandler.obtainMessage(EventHandler.EVENT_IPP_START);
        msg.sendToTarget();
	}
	
	private void startWithThrow() throws ServiceStartException {
		if(null == mEvent) throw new ServiceStartException(
				"To start the ipp service, you must call method registerIppEvent() first.");
	}
	
	public void registerIppEvent(IIppEvent event) {
		mEvent = event;
	}
	
	private class EventHandler extends Handler {
	    public static final int EVENT_IPP_START = 0x10;
	    public static final int EVENT_IPP_STOP  = 0x11;
	    public static final int EVENT_IPP_DESTORY = 0x12;
	    
	    public EventHandler(Looper looper) {
	        super(looper);
	    }
	
	    @Override
	    public void handleMessage(Message msg) {
	        switch (msg.what) {
	            case EVENT_IPP_START :
	                IppCoreJni.initCore(new IppEvent());
	                break;
	            case EVENT_IPP_STOP :
	                IppCoreJni.deinitCore();
	                break;
	            case EVENT_IPP_DESTORY :
	                getLooper().quit();
	                break;
	        }
	    }
	}
	
	public static class IppEvent implements IIppEvent {
		@Override
		public void onUpdateValuesList(List<IppEventMsg> events) {
			if (mEvent != null)
				mEvent.onUpdateValuesList(events);
		}

		@Override
		public void onDeviceRemove(int id) {
			Log.v(TAG, "onDeviceRemove" + id);
			if (mEvent != null)
				mEvent.onDeviceRemove(id);
		}

		@Override
		public void onDeviceAdd(IppDevice newdevice) {
			Log.v(TAG, "onDeviceAdd" + newdevice.getDeviceID());
			if (mEvent != null)
				mEvent.onDeviceAdd(newdevice);
		}

		@Override
		public void onDeviceEventUpdate(int eventtype, int eventvalue) {
			Log.v(TAG, "onDeviceEventUpdate");
			if (mEvent != null)
				mEvent.onDeviceEventUpdate(eventtype, eventvalue);
		}

		@Override
		public void onIPPDeviceSetAck(IppDevice dev, int funid, int isok) {
			if (mEvent != null)
				mEvent.onIPPDeviceSetAck(dev, funid, isok);
		}

		@Override
		public void onIPPNetworkDisconnect() {
			if (mEvent != null)
				mEvent.onIPPNetworkDisconnect();
		}

		@Override
		public void onDeviceEventReport(IppDevice dev, int eventtype,
				int param1, String param2) {
			if (mEvent != null)
				mEvent.onDeviceEventReport(dev, eventtype, param1, param2);
		}

		@Override
		public void onSendVoiceMsgResponse(int recvusr, boolean success) {
			if (mEvent != null)
				mEvent.onSendVoiceMsgResponse(recvusr, success);
		}

		

		@Override
		public void onRecvVoiceMsg(VoiceMsg msg) {
			if (mEvent != null)
				mEvent.onRecvVoiceMsg(msg);
		}

		@Override
		public void onIPPDeviceChannelChange(String ownerID, String devsn,
				String channelid, String channelname) {
			if (mEvent != null)
				mEvent.onIPPDeviceChannelChange(ownerID, devsn, channelid,
						channelname);
		}

		@Override
		public void onKickOff(String userid, int logintype, String msg) {
			if (mEvent != null)
				mEvent.onKickOff(userid, logintype, msg);
		}

		@Override
		public void onFriendOnline(String friendID, boolean online) {
			if (mEvent != null)
				mEvent.onFriendOnline(friendID, online);
		}

		@Override
		public void onDeviceOnline(String ownerID, String devsn, int devtype,
				boolean online) {
			if (mEvent != null)
				mEvent.onDeviceOnline(ownerID, devsn, devtype, online);
		}

		@Override
		public void onMsgReceived(IPPMsg msg) {
			if (mEvent != null)
				mEvent.onMsgReceived(msg);
		}

		@Override
		public void onMinaReturn(String json) {
			if (mEvent != null)
				mEvent.onMinaReturn(json);
		}

		@Override
		public void onGetScreen(int devid,byte[] bitmap) {
			if (mEvent != null)
				mEvent.onGetScreen(devid,bitmap);
		}

		@Override
		public void OnStatusReport(String uuid, String heaterstatus) {
			if (mEvent != null)
				mEvent.OnStatusReport(uuid,heaterstatus);
		}

		@Override
		public void OnSendHocoStatus(int id, IppHocoStatus status) {
			if(mEvent != null)
				mEvent.OnSendHighHocoStatus(id, status);
		}

		@Override
		public void OnErrorSend(int id, int mError, int mErrorValue) {
			if(mEvent != null){
				mEvent.OnErrorSend(id, mError, mErrorValue);
			}
		}

		@Override
		public void OnSendCookerTotalTime(int id, int cookernum, int totaltime) {
			if (mEvent != null)
				mEvent.OnSendCookerTotalTime(id, cookernum, totaltime);
		}

		@Override
		public void OnSendCookerTimeLeft(int id, int timenum, int timeleft) {
			if(mEvent != null)
				mEvent.OnSendCookerTimeLeft(id, timenum, timeleft);
		}

		@Override
		public void OnSendHighHocoStatus(int id, IppHocoStatus status) {
			if(mEvent !=null)
				mEvent.OnSendHighHocoStatus(id, status);
		}

		@Override
		public void onDeviceEvent(IppDevice dev, String data, int length) {
			
		}

		@Override
		public void onDeviceEvent(IppDevice dev, byte[] data) {
//			Log.d("", "onDeviceEvent");
			if (mEvent != null)
				mEvent.onDeviceEvent(dev,data);
			
		}

	}
}